@@ -1,63 +1,51 @@
-import Vue from 'vue';
-import Router from 'vue-router';
-import ViewPrivate from './components/ViewPrivate';
-import ViewBookmarklet from './components/ViewBookmarklet';
-import { generateUrl } from 'nextcloud-router';
+import Vue from 'vue'
+import Router from 'vue-router'
+import ViewPrivate from './components/ViewPrivate'
+import ViewBookmarklet from './components/ViewBookmarklet'
+import { generateUrl } from 'nextcloud-router'
 
-Vue.use(Router);
+Vue.use(Router)
 
 export default new Router({
-	mode: 'hash',
+	mode: 'history',
 	base: generateUrl('/apps/bookmarks'),
 	linkActiveClass: 'active',
 	routes: [
 		{
 			path: '/',
 			name: 'home',
-			component: ViewPrivate
+			component: ViewPrivate,
 		},
 		{
 			path: '/recent',
 			name: 'recent',
-			component: ViewPrivate
+			component: ViewPrivate,
 		},
 		{
 			path: '/search/:search',
 			name: 'search',
-			component: ViewPrivate
+			component: ViewPrivate,
 		},
 		{
 			path: '/folder/:folder',
 			name: 'folder',
-			component: ViewPrivate
+			component: ViewPrivate,
 		},
 		{
 			path: '/tags/:tags',
 			name: 'tags',
-			component: ViewPrivate
+			component: ViewPrivate,
 		},
 		{
 			path: '/untagged',
 			name: 'untagged',
-			component: ViewPrivate
+			component: ViewPrivate,
 		},
 		{
 			path: '/bookmarklet',
 			name: 'bookmarklet',
 			component: ViewBookmarklet,
-			props: true
+			props: (route) => ({ url: route.query.url, title: route.query.title }),
 		},
-		{
-			path: '/bookmarklet/:url',
-			name: 'bookmarklet',
-			component: ViewBookmarklet,
-			props: true
-		},
-		{
-			path: '/bookmarklet/:url/:title',
-			name: 'bookmarklet',
-			component: ViewBookmarklet,
-			props: true
-		}
-	]
-});
+	],
+})
